@@ -32,6 +32,7 @@ index((scanl), 6, apply, apply).
 index((scanl), 7, apply, apply).
 index((expand_phrase), 2, apply_macros, apply_macros).
 index((expand_phrase), 4, apply_macros, apply_macros).
+index((apply_macros_sentinel), 0, apply_macros, apply_macros).
 index((arithmetic_function), 1, arithmetic, arithmetic).
 index((arithmetic_expression_value), 2, arithmetic, arithmetic).
 index((empty_assoc), 1, assoc, assoc).
@@ -129,8 +130,6 @@ index((unlisten), 3, broadcast, broadcast).
 index((listening), 3, broadcast, broadcast).
 index((broadcast), 1, broadcast, broadcast).
 index((broadcast_request), 1, broadcast, broadcast).
-index((xml_write_canonical), 3, c14n2, c14n2).
-index((cgi_get_form), 1, cgi, cgi).
 index((format_to_chars), 3, charsio, charsio).
 index((format_to_chars), 4, charsio, charsio).
 index((write_to_chars), 2, charsio, charsio).
@@ -182,36 +181,6 @@ index((with_output_to_codes), 2, codesio, codesio).
 index((with_output_to_codes), 3, codesio, codesio).
 index((with_output_to_codes), 4, codesio, codesio).
 index((coinductive), 1, coinduction, coinduction).
-index((crypt), 2, crypt, crypt).
-index((crypto_n_random_bytes), 2, crypto, crypto).
-index((crypto_data_hash), 3, crypto, crypto).
-index((crypto_file_hash), 3, crypto, crypto).
-index((crypto_context_new), 2, crypto, crypto).
-index((crypto_data_context), 3, crypto, crypto).
-index((crypto_context_hash), 2, crypto, crypto).
-index((crypto_open_hash_stream), 3, crypto, crypto).
-index((crypto_stream_hash), 2, crypto, crypto).
-index((crypto_password_hash), 2, crypto, crypto).
-index((crypto_password_hash), 3, crypto, crypto).
-index((crypto_data_hkdf), 4, crypto, crypto).
-index((ecdsa_sign), 4, crypto, crypto).
-index((ecdsa_verify), 4, crypto, crypto).
-index((crypto_data_decrypt), 6, crypto, crypto).
-index((crypto_data_encrypt), 6, crypto, crypto).
-index((hex_bytes), 2, crypto, crypto).
-index((rsa_private_decrypt), 4, crypto, crypto).
-index((rsa_private_encrypt), 4, crypto, crypto).
-index((rsa_public_decrypt), 4, crypto, crypto).
-index((rsa_public_encrypt), 4, crypto, crypto).
-index((rsa_sign), 4, crypto, crypto).
-index((rsa_verify), 4, crypto, crypto).
-index((crypto_modular_inverse), 3, crypto, crypto).
-index((crypto_generate_prime), 3, crypto, crypto).
-index((crypto_is_prime), 2, crypto, crypto).
-index((crypto_name_curve), 2, crypto, crypto).
-index((crypto_curve_order), 2, crypto, crypto).
-index((crypto_curve_generator), 2, crypto, crypto).
-index((crypto_curve_scalar_mult), 4, crypto, crypto).
 index((csv), 3, csv, csv).
 index((csv), 4, csv, csv).
 index((csv_read_file), 2, csv, csv).
@@ -308,17 +277,6 @@ index((fast_write), 2, fastrw, fastrw).
 index((fast_write_to_string), 3, fastrw, fastrw).
 index((can_open_file), 2, files, files).
 index((chdir), 1, files, files).
-index((set_time_file), 3, files_ex, filesex).
-index((link_file), 3, files_ex, filesex).
-index((chmod), 2, files_ex, filesex).
-index((relative_file_name), 3, files_ex, filesex).
-index((directory_file_path), 3, files_ex, filesex).
-index((directory_member), 3, files_ex, filesex).
-index((copy_file), 2, files_ex, filesex).
-index((make_directory_path), 1, files_ex, filesex).
-index((copy_directory), 2, files_ex, filesex).
-index((delete_directory_and_contents), 1, files_ex, filesex).
-index((delete_directory_contents), 1, files_ex, filesex).
 index((reset_gensym), 0, gensym, gensym).
 index((reset_gensym), 1, gensym, gensym).
 index((gensym), 2, gensym, gensym).
@@ -334,13 +292,14 @@ index((git_ls_remote), 3, git, git).
 index((git_branches), 2, git, git).
 index((git_remote_branches), 2, git, git).
 index((git_default_branch), 2, git, git).
+index((git_current_branch), 2, git, git).
+index((git_tags), 2, git, git).
 index((git_tags_on_branch), 3, git, git).
 index((git_shortlog), 3, git, git).
 index((git_log_data), 3, git, git).
 index((git_show), 4, git, git).
 index((git_commit_data), 3, git, git).
-index((open_hash_stream), 3, hash_stream, hash_stream).
-index((stream_hash), 2, hash_stream, hash_stream).
+index((is_git_hash), 1, git, git).
 index((ht_new), 1, hashtable, hashtable).
 index((ht_is_hashtable), 1, hashtable, hashtable).
 index((ht_size), 2, hashtable, hashtable).
@@ -388,9 +347,6 @@ index((send_signal), 1, intercept, intercept).
 index((send_silent_signal), 1, intercept, intercept).
 index((open_any), 5, iostream, iostream).
 index((close_any), 1, iostream, iostream).
-index((iso_639_2), 2, iso_639, iso_639).
-index((iso_639_3), 2, iso_639, iso_639).
-index((iso_639), 2, iso_639, iso_639).
 index((lazy_list), 2, lazy_lists, lazy_lists).
 index((lazy_list), 3, lazy_lists, lazy_lists).
 index((lazy_list_materialize), 1, lazy_lists, lazy_lists).
@@ -460,25 +416,6 @@ index((cli_debug_opt_meta), 2, prolog_main, main).
 index((cli_enable_development_system), 0, prolog_main, main).
 index((make), 0, make, make).
 index((make_reload_file), 1, make, make).
-index((md5_hash), 3, md5, md5).
-index((new_memory_file), 1, memory_file, memfile).
-index((free_memory_file), 1, memory_file, memfile).
-index((size_memory_file), 2, memory_file, memfile).
-index((size_memory_file), 3, memory_file, memfile).
-index((open_memory_file), 3, memory_file, memfile).
-index((open_memory_file), 4, memory_file, memfile).
-index((insert_memory_file), 3, memory_file, memfile).
-index((delete_memory_file), 3, memory_file, memfile).
-index((atom_to_memory_file), 2, memory_file, memfile).
-index((memory_file_to_atom), 2, memory_file, memfile).
-index((memory_file_to_codes), 2, memory_file, memfile).
-index((memory_file_to_string), 2, memory_file, memfile).
-index((memory_file_to_atom), 3, memory_file, memfile).
-index((memory_file_to_codes), 3, memory_file, memfile).
-index((memory_file_to_string), 3, memory_file, memfile).
-index((memory_file_substring), 5, memory_file, memfile).
-index((memory_file_line_position), 4, memory_file, memfile).
-index((utf8_position_memory_file), 3, memory_file, memfile).
 index((in_temporary_module), 3, modules, modules).
 index((current_temporary_module), 1, modules, modules).
 index((nb_rb_insert), 3, nb_rbtrees, nb_rbtrees).
@@ -551,18 +488,6 @@ index((pairs_keys), 2, pairs, pairs).
 index((group_pairs_by_key), 2, pairs, pairs).
 index((transpose_pairs), 2, pairs, pairs).
 index((map_list_to_pairs), 3, pairs, pairs).
-index((re_match), 2, pcre, pcre).
-index((re_match), 3, pcre, pcre).
-index((re_matchsub), 3, pcre, pcre).
-index((re_matchsub), 4, pcre, pcre).
-index((re_foldl), 6, pcre, pcre).
-index((re_split), 3, pcre, pcre).
-index((re_split), 4, pcre, pcre).
-index((re_replace), 4, pcre, pcre).
-index((re_replace), 5, pcre, pcre).
-index((re_compile), 3, pcre, pcre).
-index((re_flush), 0, pcre, pcre).
-index((re_config), 1, pcre, pcre).
 index((persistent), 1, persistency, persistency).
 index((current_persistent_predicate), 1, persistency, persistency).
 index((db_attach), 2, persistency, persistency).
@@ -570,22 +495,9 @@ index((db_detach), 0, persistency, persistency).
 index((db_attached), 1, persistency, persistency).
 index((db_sync), 1, persistency, persistency).
 index((db_sync_all), 1, persistency, persistency).
-index((set_test_options), 1, plunit, plunit).
-index((begin_tests), 1, plunit, plunit).
-index((begin_tests), 2, plunit, plunit).
-index((end_tests), 1, plunit, plunit).
-index((run_tests), 0, plunit, plunit).
-index((run_tests), 1, plunit, plunit).
-index((run_tests), 2, plunit, plunit).
-index((load_test_files), 1, plunit, plunit).
-index((running_tests), 0, plunit, plunit).
-index((current_test), 5, plunit, plunit).
-index((current_test_unit), 2, plunit, plunit).
-index((test_report), 1, plunit, plunit).
 index((portray_text), 1, portray_text, portray_text).
 index((set_portray_text), 2, portray_text, portray_text).
 index((set_portray_text), 3, portray_text, portray_text).
-index(('$portray_text_enabled'), 1, portray_text, portray_text).
 index((print_term), 2, prolog_pretty_print, pprint).
 index((predicate_options), 3, predicate_options, predicate_options).
 index((assert_predicate_options), 4, predicate_options, predicate_options).
@@ -599,18 +511,6 @@ index((derived_predicate_options), 1, predicate_options, predicate_options).
 index((check_predicate_options), 0, predicate_options, predicate_options).
 index((derive_predicate_options), 0, predicate_options, predicate_options).
 index((check_predicate_options), 1, predicate_options, predicate_options).
-index((process_create), 3, process, process).
-index((process_wait), 2, process, process).
-index((process_wait), 3, process, process).
-index((process_id), 1, process, process).
-index((process_id), 2, process, process).
-index((is_process), 1, process, process).
-index((process_release), 1, process, process).
-index((process_kill), 1, process, process).
-index((process_group_kill), 1, process, process).
-index((process_group_kill), 2, process, process).
-index((process_kill), 2, process, process).
-index((process_set_method), 1, process, process).
 index((autoload_all), 0, prolog_autoload, prolog_autoload).
 index((autoload_all), 1, prolog_autoload, prolog_autoload).
 index((set_breakpoint), 4, prolog_breakpoints, prolog_breakpoints).
@@ -645,7 +545,15 @@ index((prolog_colourise_query), 3, prolog_colour, prolog_colour).
 index((syntax_colour), 2, prolog_colour, prolog_colour).
 index((syntax_message), 3, prolog_colour, prolog_colour).
 index((prolog_dump_runtime_variables), 0, prolog_config, prolog_config).
-index((apple_bundle_libdir), 1, prolog_config, prolog_config).
+index((prolog_config), 2, prolog_config, prolog_config).
+index((coverage), 1, prolog_coverage, prolog_coverage).
+index((coverage), 2, prolog_coverage, prolog_coverage).
+index((show_coverage), 1, prolog_coverage, prolog_coverage).
+index((show_coverage), 2, prolog_coverage, prolog_coverage).
+index((cov_save_data), 2, prolog_coverage, prolog_coverage).
+index((cov_load_data), 2, prolog_coverage, prolog_coverage).
+index((cov_reset), 0, prolog_coverage, prolog_coverage).
+index((cov_property), 1, prolog_coverage, prolog_coverage).
 index((spy), 1, prolog_debug_tools, prolog_debug).
 index((nospy), 1, prolog_debug_tools, prolog_debug).
 index((nospyall), 0, prolog_debug_tools, prolog_debug).
@@ -659,10 +567,6 @@ index((format_spec), 2, prolog_format, prolog_format).
 index((format_spec), 3, prolog_format, prolog_format).
 index((format_types), 2, prolog_format, prolog_format).
 index((prolog_history), 1, prolog_history, prolog_history).
-index((qcompile_libraries), 0, prolog_install, prolog_install).
-index((cmake_qcompile), 0, prolog_install, prolog_install).
-index((cmake_qcompile), 2, prolog_install, prolog_install).
-index((cmake_save_man_index), 0, prolog_install, prolog_install).
 index((jiti_list), 0, prolog_jiti, prolog_jiti).
 index((jiti_list), 1, prolog_jiti, prolog_jiti).
 index((infer_meta_predicate), 2, prolog_metainference, prolog_metainference).
@@ -670,22 +574,23 @@ index((inferred_meta_predicate), 2, prolog_metainference, prolog_metainference).
 index((pack_list_installed), 0, prolog_pack, prolog_pack).
 index((pack_info), 1, prolog_pack, prolog_pack).
 index((pack_list), 1, prolog_pack, prolog_pack).
+index((pack_list), 2, prolog_pack, prolog_pack).
 index((pack_search), 1, prolog_pack, prolog_pack).
 index((pack_install), 1, prolog_pack, prolog_pack).
 index((pack_install), 2, prolog_pack, prolog_pack).
+index((pack_install_local), 3, prolog_pack, prolog_pack).
 index((pack_upgrade), 1, prolog_pack, prolog_pack).
 index((pack_rebuild), 1, prolog_pack, prolog_pack).
 index((pack_rebuild), 0, prolog_pack, prolog_pack).
 index((pack_remove), 1, prolog_pack, prolog_pack).
+index((pack_remove), 2, prolog_pack, prolog_pack).
+index((pack_publish), 2, prolog_pack, prolog_pack).
 index((pack_property), 2, prolog_pack, prolog_pack).
-index((pack_attach), 2, prolog_pack, prolog_pack).
-index((pack_url_file), 2, prolog_pack, prolog_pack).
 index((profile), 1, prolog_profile, prolog_profile).
 index((profile), 2, prolog_profile, prolog_profile).
 index((show_profile), 1, prolog_profile, prolog_profile).
 index((profile_data), 1, prolog_profile, prolog_profile).
 index((profile_procedure_data), 2, prolog_profile, prolog_profile).
-index((prolog_server), 2, prolog_server, prolog_server).
 index((prolog_read_source_term), 4, prolog_source, prolog_source).
 index((read_source_term_at_location), 3, prolog_source, prolog_source).
 index((prolog_open_source), 2, prolog_source, prolog_source).
@@ -705,13 +610,14 @@ index((print_prolog_backtrace), 3, prolog_stack, prolog_stack).
 index((backtrace), 1, prolog_stack, prolog_stack).
 index((print_last_choicepoint), 0, prolog_stack, prolog_stack).
 index((print_last_choicepoint), 2, prolog_stack, prolog_stack).
-index((open_prolog_stream), 4, prolog_stream, prolog_stream).
 index((trace), 1, prolog_trace, prolog_trace).
 index((trace), 2, prolog_trace, prolog_trace).
 index((tracing), 2, prolog_trace, prolog_trace).
 index((list_tracing), 0, prolog_trace, prolog_trace).
 index((notraceall), 0, prolog_trace, prolog_trace).
 index((require_prolog_version), 2, prolog_versions, prolog_versions).
+index((require_version), 3, prolog_versions, prolog_versions).
+index((cmp_versions), 3, prolog_versions, prolog_versions).
 index((wrap_predicate), 4, prolog_wrap, prolog_wrap).
 index((unwrap_predicate), 2, prolog_wrap, prolog_wrap).
 index((current_predicate_wrapper), 4, prolog_wrap, prolog_wrap).
@@ -753,9 +659,6 @@ index((stream_to_lazy_list), 2, pure_input, pure_input).
 index((syntax_error), 3, pure_input, pure_input).
 index((lazy_list_location), 3, pure_input, pure_input).
 index((lazy_list_character_count), 3, pure_input, pure_input).
-index((pwp_files), 2, pwp, pwp).
-index((pwp_stream), 3, pwp, pwp).
-index((pwp_xml), 3, pwp, pwp).
 index((load_foreign_files), 0, qp_foreign, qpforeign).
 index((load_foreign_files), 2, qp_foreign, qpforeign).
 index((load_foreign_files), 3, qp_foreign, qpforeign).
@@ -864,10 +767,8 @@ index((read_file_to_terms), 3, read_util, readutil).
 index((record), 1, record, record).
 index((current_record), 2, record, record).
 index((current_record_predicate), 2, record, record).
-index((rlimit), 3, clib_rlimit, rlimit).
 index((with_rwlock), 3, rwlocks, rwlocks).
 index((with_rwlock), 4, rwlocks, rwlocks).
-index((saml_authenticate), 4, saml, saml).
 index((safe_goal), 1, sandbox, sandbox).
 index((safe_call), 1, sandbox, sandbox).
 index((setting), 4, settings, settings).
@@ -884,54 +785,6 @@ index((setting_property), 2, settings, settings).
 index((list_settings), 0, settings, settings).
 index((list_settings), 1, settings, settings).
 index((convert_setting_text), 3, settings, settings).
-index((load_html), 3, sgml, sgml).
-index((load_xml), 3, sgml, sgml).
-index((load_sgml), 3, sgml, sgml).
-index((load_sgml_file), 2, sgml, sgml).
-index((load_xml_file), 2, sgml, sgml).
-index((load_html_file), 2, sgml, sgml).
-index((load_structure), 3, sgml, sgml).
-index((load_dtd), 2, sgml, sgml).
-index((load_dtd), 3, sgml, sgml).
-index((dtd), 2, sgml, sgml).
-index((dtd_property), 2, sgml, sgml).
-index((new_dtd), 2, sgml, sgml).
-index((free_dtd), 1, sgml, sgml).
-index((open_dtd), 3, sgml, sgml).
-index((new_sgml_parser), 2, sgml, sgml).
-index((free_sgml_parser), 1, sgml, sgml).
-index((set_sgml_parser), 2, sgml, sgml).
-index((get_sgml_parser), 2, sgml, sgml).
-index((sgml_parse), 2, sgml, sgml).
-index((sgml_register_catalog_file), 2, sgml, sgml).
-index((xml_quote_attribute), 3, sgml, sgml).
-index((xml_quote_cdata), 3, sgml, sgml).
-index((xml_quote_attribute), 2, sgml, sgml).
-index((xml_quote_cdata), 2, sgml, sgml).
-index((xml_name), 1, sgml, sgml).
-index((xml_name), 2, sgml, sgml).
-index((xsd_number_string), 2, sgml, sgml).
-index((xsd_time_string), 3, sgml, sgml).
-index((xml_basechar), 1, sgml, sgml).
-index((xml_ideographic), 1, sgml, sgml).
-index((xml_combining_char), 1, sgml, sgml).
-index((xml_digit), 1, sgml, sgml).
-index((xml_extender), 1, sgml, sgml).
-index((iri_xml_namespace), 2, sgml, sgml).
-index((iri_xml_namespace), 3, sgml, sgml).
-index((xml_is_dom), 1, sgml, sgml).
-index((html_write), 2, sgml_write, sgml_write).
-index((html_write), 3, sgml_write, sgml_write).
-index((sgml_write), 2, sgml_write, sgml_write).
-index((sgml_write), 3, sgml_write, sgml_write).
-index((xml_write), 2, sgml_write, sgml_write).
-index((xml_write), 3, sgml_write, sgml_write).
-index((sha_hash), 3, crypto_hash, sha).
-index((sha_new_ctx), 2, crypto_hash, sha).
-index((sha_hash_ctx), 4, crypto_hash, sha).
-index((hmac_sha), 4, crypto_hash, sha).
-index((file_sha1), 2, crypto_hash, sha).
-index((hash_atom), 2, crypto_hash, sha).
 index((shell), 0, shell, shell).
 index((ls), 0, shell, shell).
 index((ls), 1, shell, shell).
@@ -952,29 +805,6 @@ index((current_foreign_library), 2, shlib, shlib).
 index((reload_foreign_libraries), 0, shlib, shlib).
 index((use_foreign_library), 1, shlib, shlib).
 index((use_foreign_library), 2, shlib, shlib).
-index((socket_create), 2, socket, socket).
-index((tcp_socket), 1, socket, socket).
-index((tcp_close_socket), 1, socket, socket).
-index((tcp_open_socket), 3, socket, socket).
-index((tcp_connect), 2, socket, socket).
-index((tcp_connect), 3, socket, socket).
-index((tcp_connect), 4, socket, socket).
-index((tcp_bind), 2, socket, socket).
-index((tcp_accept), 3, socket, socket).
-index((tcp_listen), 2, socket, socket).
-index((tcp_fcntl), 3, socket, socket).
-index((tcp_setopt), 2, socket, socket).
-index((tcp_getopt), 2, socket, socket).
-index((host_address), 3, socket, socket).
-index((tcp_host_to_address), 2, socket, socket).
-index((tcp_select), 3, socket, socket).
-index((gethostname), 1, socket, socket).
-index((ip_name), 2, socket, socket).
-index((tcp_open_socket), 2, socket, socket).
-index((udp_socket), 1, socket, socket).
-index((udp_receive), 4, socket, socket).
-index((udp_send), 4, socket, socket).
-index((negotiate_socks_connection), 2, socket, socket).
 index((distinct), 1, solution_sequences, solution_sequences).
 index((distinct), 2, solution_sequences, solution_sequences).
 index((reduced), 1, solution_sequences, solution_sequences).
@@ -986,39 +816,12 @@ index((order_by), 2, solution_sequences, solution_sequences).
 index((group_by), 4, solution_sequences, solution_sequences).
 index((predsort), 3, sort, sort).
 index((locale_sort), 2, sort, sort).
-index((certificate_field), 2, ssl, ssl).
-index((load_certificate), 2, ssl, ssl).
-index((load_private_key), 3, ssl, ssl).
-index((load_public_key), 2, ssl, ssl).
-index((load_crl), 2, ssl, ssl).
-index((write_certificate), 3, ssl, ssl).
-index((system_root_certificates), 1, ssl, ssl).
-index((cert_accept_any), 5, ssl, ssl).
-index((same_certificate), 2, ssl, ssl).
-index((ssl_context), 3, ssl, ssl).
-index((ssl_add_certificate_key), 4, ssl, ssl).
-index((ssl_set_options), 3, ssl, ssl).
-index((ssl_property), 2, ssl, ssl).
-index((ssl_negotiate), 5, ssl, ssl).
-index((ssl_peer_certificate), 2, ssl, ssl).
-index((ssl_peer_certificate_chain), 2, ssl, ssl).
-index((ssl_session), 2, ssl, ssl).
-index((ssl_secure_ciphers), 1, ssl, ssl).
-index((verify_certificate), 3, ssl, ssl).
-index((verify_certificate_issuer), 2, ssl, ssl).
-index((ssl_upgrade_legacy_options), 2, ssl, ssl).
 index((statistics), 0, prolog_statistics, statistics).
 index((statistics), 1, prolog_statistics, statistics).
 index((thread_statistics), 2, prolog_statistics, statistics).
 index((time), 1, prolog_statistics, statistics).
 index((call_time), 2, prolog_statistics, statistics).
 index((call_time), 3, prolog_statistics, statistics).
-index((stream_info), 1, stream_info, streaminfo).
-index((add_stream_to_pool), 2, stream_pool, streampool).
-index((delete_stream_from_pool), 1, stream_pool, streampool).
-index((close_stream_pool), 0, stream_pool, streampool).
-index((dispatch_stream_pool), 1, stream_pool, streampool).
-index((stream_pool_main_loop), 0, stream_pool, streampool).
 index((with_output_to), 3, streams, streams).
 index((dedent_lines), 3, strings, strings).
 index((indent_lines), 3, strings, strings).
@@ -1026,35 +829,10 @@ index((indent_lines), 4, strings, strings).
 index((interpolate_string), 4, strings, strings).
 index((string_lines), 2, strings, strings).
 index((string), 4, strings, strings).
-index((openlog), 3, syslog, syslog).
-index((syslog), 2, syslog, syslog).
-index((syslog), 3, syslog, syslog).
-index((closelog), 0, syslog, syslog).
 index((lock_predicate), 1, swi_system_utilities, system).
 index((unlock_predicate), 1, swi_system_utilities, system).
 index((system_mode), 1, swi_system_utilities, system).
 index((system_module), 0, swi_system_utilities, system).
-index((new_table), 4, table, table).
-index((open_table), 1, table, table).
-index((close_table), 1, table, table).
-index((free_table), 1, table, table).
-index((table_window), 3, table, table).
-index((read_table_record), 4, table, table).
-index((read_table_record_data), 4, table, table).
-index((read_table_fields), 4, table, table).
-index((get_table_attribute), 3, table, table).
-index((table_previous_record), 3, table, table).
-index((table_start_of_record), 4, table, table).
-index((in_table), 3, table, table).
-index((new_order_table), 2, table, table).
-index((order_table_mapping), 3, table, table).
-index((compare_strings), 4, table, table).
-index((prefix_string), 3, table, table).
-index((prefix_string), 4, table, table).
-index((sub_string), 3, table, table).
-index((table_version), 2, table, table).
-index((sort_table), 2, table_util, table_util).
-index((verify_table_order), 1, table_util, table_util).
 index((abolish_all_tables), 0, tables, tables).
 index((abolish_module_tables), 1, tables, tables).
 index((abolish_table_pred), 1, tables, tables).
@@ -1093,10 +871,6 @@ index((foldsubterms), 5, terms, terms).
 index((same_functor), 2, terms, terms).
 index((same_functor), 3, terms, terms).
 index((same_functor), 4, terms, terms).
-index((show_coverage), 1, prolog_cover, test_cover).
-index((show_coverage), 2, prolog_cover, test_cover).
-index((make_tests), 3, test_wizard, test_wizard).
-index((make_test), 3, test_wizard, test_wizard).
 index((concurrent), 3, thread, thread).
 index((concurrent_maplist), 2, thread, thread).
 index((concurrent_maplist), 3, thread, thread).
@@ -1129,25 +903,9 @@ index((tnodebug), 1, thread_util, threadutil).
 index((tprofile), 1, thread_util, threadutil).
 index((tbacktrace), 1, thread_util, threadutil).
 index((tbacktrace), 2, thread_util, threadutil).
-index((alarm), 3, time, time).
-index((alarm), 4, time, time).
-index((alarm_at), 3, time, time).
-index((alarm_at), 4, time, time).
-index((remove_alarm), 1, time, time).
-index((install_alarm), 1, time, time).
-index((install_alarm), 2, time, time).
-index((uninstall_alarm), 1, time, time).
-index((current_alarm), 4, time, time).
-index((call_with_time_limit), 2, time, time).
-index((call_with_time_limit), 3, time, time).
 index((tty_clear), 0, tty, tty).
 index((tty_flash), 0, tty, tty).
 index((menu), 3, tty, tty).
-index((udp_broadcast_initialize), 2, udp_broadcast, udp_broadcast).
-index((udp_broadcast_close), 1, udp_broadcast, udp_broadcast).
-index((udp_peer_add), 2, udp_broadcast, udp_broadcast).
-index((udp_peer_del), 2, udp_broadcast, udp_broadcast).
-index((udp_peer), 2, udp_broadcast, udp_broadcast).
 index((add_edges), 3, ugraphs, ugraphs).
 index((add_vertices), 3, ugraphs, ugraphs).
 index((complement), 2, ugraphs, ugraphs).
@@ -1166,55 +924,6 @@ index((vertices), 2, ugraphs, ugraphs).
 index((vertices_edges_to_ugraph), 3, ugraphs, ugraphs).
 index((ugraph_union), 3, ugraphs, ugraphs).
 index((connect_ugraph), 3, ugraphs, ugraphs).
-index((getuid), 1, uid, uid).
-index((getgid), 1, uid, uid).
-index((geteuid), 1, uid, uid).
-index((getegid), 1, uid, uid).
-index((getgroups), 1, uid, uid).
-index((user_info), 2, uid, uid).
-index((group_info), 2, uid, uid).
-index((user_data), 3, uid, uid).
-index((group_data), 3, uid, uid).
-index((setuid), 1, uid, uid).
-index((setgid), 1, uid, uid).
-index((seteuid), 1, uid, uid).
-index((setegid), 1, uid, uid).
-index((set_user_and_group), 1, uid, uid).
-index((set_user_and_group), 2, uid, uid).
-index((unicode_property), 2, unicode, unicode).
-index((unicode_map), 3, unicode, unicode).
-index((unicode_nfd), 2, unicode, unicode).
-index((unicode_nfc), 2, unicode, unicode).
-index((unicode_nfkd), 2, unicode, unicode).
-index((unicode_nfkc), 2, unicode, unicode).
-index((fork), 1, unix, unix).
-index((exec), 1, unix, unix).
-index((fork_exec), 1, unix, unix).
-index((wait), 2, unix, unix).
-index((kill), 2, unix, unix).
-index((pipe), 2, unix, unix).
-index((dup), 2, unix, unix).
-index((detach_IO), 0, unix, unix).
-index((detach_IO), 1, unix, unix).
-index((environ), 1, unix, unix).
-index((uri_components), 2, uri, uri).
-index((uri_data), 3, uri, uri).
-index((uri_data), 4, uri, uri).
-index((uri_edit), 3, uri, uri).
-index((uri_normalized), 2, uri, uri).
-index((iri_normalized), 2, uri, uri).
-index((uri_normalized_iri), 2, uri, uri).
-index((uri_normalized), 3, uri, uri).
-index((iri_normalized), 3, uri, uri).
-index((uri_normalized_iri), 3, uri, uri).
-index((uri_resolve), 3, uri, uri).
-index((uri_is_global), 1, uri, uri).
-index((uri_query_components), 2, uri, uri).
-index((uri_authority_components), 2, uri, uri).
-index((uri_authority_data), 3, uri, uri).
-index((uri_encoded), 3, uri, uri).
-index((uri_file_name), 2, uri, uri).
-index((uri_iri), 2, uri, uri).
 index((parse_url), 2, url, url).
 index((parse_url), 3, url, url).
 index((is_absolute_url), 1, url, url).
@@ -1226,9 +935,6 @@ index((url_iri), 2, url, url).
 index((file_name_to_url), 2, url, url).
 index((set_url_encoding), 2, url, url).
 index((utf8_codes), 3, utf8, utf8).
-index((uuid), 1, uuid, uuid).
-index((uuid), 2, uuid, uuid).
-index((uuid_property), 2, uuid, uuid).
 index((numbervars), 1, varnumbers, varnumbers).
 index((varnumbers), 2, varnumbers, varnumbers).
 index((max_var_number), 3, varnumbers, varnumbers).
@@ -1248,17 +954,6 @@ index((swritef), 2, writef, writef).
 index((swritef), 3, writef, writef).
 index((www_open_url), 1, www_browser, www_browser).
 index((expand_url_path), 2, www_browser, www_browser).
-index((xmld_signed_DOM), 3, xmldsig, xmldsig).
-index((xmld_verify_signature), 4, xmldsig, xmldsig).
-index((decrypt_xml), 4, xmlenc, xmlenc).
-index((load_certificate_from_base64_string), 2, xmlenc, xmlenc).
-index((xpath), 3, xpath, xpath).
-index((xpath_chk), 3, xpath, xpath).
-index((xsdp_type), 1, xsdp_type, xsdp_types).
-index((xsdp_uri_type), 2, xsdp_type, xsdp_types).
-index((xsdp_numeric_uri), 2, xsdp_type, xsdp_types).
-index((xsdp_subtype_of), 2, xsdp_type, xsdp_types).
-index((xsdp_convert), 3, xsdp_type, xsdp_types).
 index((>>), 2, yall, yall).
 index((>>), 3, yall, yall).
 index((>>), 4, yall, yall).
@@ -1287,6 +982,3 @@ index((zipper_goto), 2, zip, zip).
 index((zipper_open_current), 3, zip, zip).
 index((zipper_members), 2, zip, zip).
 index((zipper_file_info), 3, zip, zip).
-index((zopen), 3, zlib, zlib).
-index((gzopen), 3, zlib, zlib).
-index((gzopen), 4, zlib, zlib).
